summaryrefslogtreecommitdiff
path: root/core/pim/datebook/datebook.cpp
authorhakan <hakan>2002-03-09 13:07:57 (UTC)
committer hakan <hakan>2002-03-09 13:07:57 (UTC)
commit62c21e8bdbb365a64f05dd363a98abd7fc1f0558 (patch) (side-by-side diff)
treebde5aec77cc0c22a4240b16f0fc4acc41b2d162f /core/pim/datebook/datebook.cpp
parent603e969bb8cef91534a1785e27106ba71eb03ba6 (diff)
downloadopie-62c21e8bdbb365a64f05dd363a98abd7fc1f0558.zip
opie-62c21e8bdbb365a64f05dd363a98abd7fc1f0558.tar.gz
opie-62c21e8bdbb365a64f05dd363a98abd7fc1f0558.tar.bz2
Fixed today-button to show default view
Diffstat (limited to 'core/pim/datebook/datebook.cpp') (more/less context) (show whitespace changes)
-rw-r--r--core/pim/datebook/datebook.cpp59
1 files changed, 34 insertions, 25 deletions
diff --git a/core/pim/datebook/datebook.cpp b/core/pim/datebook/datebook.cpp
index 9880e2d..92dbdc8 100644
--- a/core/pim/datebook/datebook.cpp
+++ b/core/pim/datebook/datebook.cpp
@@ -170,3 +170,2 @@ DateBook::DateBook( QWidget *parent, const char *, WFlags f )
-
Config config("DateBook");
@@ -314,7 +313,6 @@ QDate DateBook::currentDate()
-void DateBook::viewDay()
-{
+void DateBook::view(int v, const QDate &d) {
+ if (v==DAY) {
initDay();
dayAction->setOn( TRUE );
- QDate d = currentDate();
dayView->setDate( d );
@@ -322,9 +320,5 @@ void DateBook::viewDay()
dayView->redraw();
-}
-
-void DateBook::viewWeek()
-{
+ } else if (v==WEEK) {
initWeek();
weekAction->setOn( TRUE );
- QDate d = currentDate();
weekView->setDate( d );
@@ -332,8 +326,5 @@ void DateBook::viewWeek()
weekView->redraw();
-}
-
-void DateBook::viewWeekLst() {
+ } else if (v==WEEKLST) {
initWeekLst();
weekLstAction->setOn( TRUE );
- QDate d=currentDate();
weekLstView->setDate(d);
@@ -341,9 +332,5 @@ void DateBook::viewWeekLst() {
weekLstView->redraw();
-}
-
-void DateBook::viewMonth()
-{
+ } else if (v==MONTH) {
initMonth();
monthAction->setOn( TRUE );
- QDate d = currentDate();
monthView->setDate( d.year(), d.month(), d.day() );
@@ -352,2 +339,27 @@ void DateBook::viewMonth()
}
+}
+
+void DateBook::viewDefault(const QDate &d) {
+ Config config("DateBook");
+ config.setGroup("Main");
+ int current=config.readNumEntry("defaultview", DAY);
+
+ view(current,d);
+}
+
+void DateBook::viewDay() {
+ view(DAY,currentDate());
+}
+
+void DateBook::viewWeek() {
+ view(WEEK,currentDate());
+}
+
+void DateBook::viewWeekLst() {
+ view(WEEKLST,currentDate());
+}
+
+void DateBook::viewMonth() {
+ view(MONTH,currentDate());
+}
@@ -420,6 +432,4 @@ void DateBook::showDay( int year, int month, int day )
{
- initDay();
- dayView->setDate( year, month, day );
- views->raiseWidget( dayView );
- dayAction->setOn( TRUE );
+ QDate d(year, month, day);
+ view(DAY,d);
}
@@ -691,5 +701,4 @@ void DateBook::slotToday()
{
- // we need to view today
- QDate dt = QDate::currentDate();
- showDay( dt.year(), dt.month(), dt.day() );
+ // we need to view today using default view
+ viewDefault(QDate::currentDate());
}